# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`selinux`](#selinux): Manage SELinux on RHEL based systems.

#### Private Classes

* `selinux::build`: Configure the system for module building
* `selinux::config`: Configure the system to use SELinux on the system.
* `selinux::package`: Manages additional packages required to support some of the functions.
* `selinux::refpolicy_package`: Manages additional packages required to support some of the functions.

### Defined types

* [`selinux::boolean`](#selinuxboolean): Manage the state of an SELinux boolean.
* [`selinux::exec_restorecon`](#selinuxexec_restorecon): A convenience wrapper around a restorecon exec
* [`selinux::fcontext`](#selinuxfcontext): For fcontext equivalences, see selinux::fcontext::equivalence
* [`selinux::fcontext::equivalence`](#selinuxfcontextequivalence): Manage SELinux fcontext equivalences
* [`selinux::module`](#selinuxmodule): Manage a SELinux module on a running system
* [`selinux::permissive`](#selinuxpermissive): Set SELinux type to permissive
* [`selinux::port`](#selinuxport): Manage a SELinux local network port context setting

### Resource types

* [`selinux_fcontext`](#selinux_fcontext): Manage SELinux fcontext definitions. You should use selinux::fcontext instead of this directly.
* [`selinux_fcontext_equivalence`](#selinux_fcontext_equivalence): Manage SELinux fcontext equivalence definitions. You should use selinux::fcontext instead of this directly.
* [`selinux_permissive`](#selinux_permissive): Manage SELinux permissive types.
* [`selinux_port`](#selinux_port): Manage SELinux port definitions. You should use selinux::port instead of this directly.

## Classes

### <a name="selinux"></a>`selinux`

Manage SELinux on RHEL based systems.

#### Examples

##### Enable enforcing mode with targeted policy

```puppet
class { 'selinux':
  mode => 'enforcing',
  type => 'targeted',
}
```

#### Parameters

The following parameters are available in the `selinux` class:

* [`package_name`](#package_name)
* [`manage_auditd_package`](#manage_auditd_package)
* [`refpolicy_package_name`](#refpolicy_package_name)
* [`mode`](#mode)
* [`type`](#type)
* [`refpolicy_makefile`](#refpolicy_makefile)
* [`manage_package`](#manage_package)
* [`auditd_package_name`](#auditd_package_name)
* [`manage_setroubleshoot_packages`](#manage_setroubleshoot_packages)
* [`setroubleshoot_package_names`](#setroubleshoot_package_names)
* [`module_build_root`](#module_build_root)
* [`default_builder`](#default_builder)
* [`boolean`](#boolean)
* [`fcontext`](#fcontext)
* [`module`](#module)
* [`permissive`](#permissive)
* [`port`](#port)
* [`exec_restorecon`](#exec_restorecon)

##### <a name="package_name"></a>`package_name`

Data type: `Variant[String[1], Array[String[1]]]`

sets the name(s) for the selinux tools package
Default value: OS dependent (see data/).

##### <a name="manage_auditd_package"></a>`manage_auditd_package`

Data type: `Boolean`

install auditd to log SELinux violations,
for OSes that do not have auditd installed by default.
Default value: OS dependent (see data/)

##### <a name="refpolicy_package_name"></a>`refpolicy_package_name`

Data type: `String`

sets the name for the refpolicy development package, required for the
refpolicy module builder
Default value: OS dependent (see data/)

##### <a name="mode"></a>`mode`

Data type: `Optional[Enum['enforcing', 'permissive', 'disabled']]`

sets the operating state for SELinux.

Default value: ``undef``

##### <a name="type"></a>`type`

Data type: `Optional[Enum['targeted', 'minimum', 'mls']]`

sets the selinux type

Default value: ``undef``

##### <a name="refpolicy_makefile"></a>`refpolicy_makefile`

Data type: `Stdlib::Absolutepath`

the path to the system's SELinux makefile for the refpolicy framework

Default value: `'/usr/share/selinux/devel/Makefile'`

##### <a name="manage_package"></a>`manage_package`

Data type: `Boolean`

manage the package for selinux tools and refpolicy

Default value: ``true``

##### <a name="auditd_package_name"></a>`auditd_package_name`

Data type: `String[1]`

used when `manage_auditd_package` is true

Default value: `'auditd'`

##### <a name="manage_setroubleshoot_packages"></a>`manage_setroubleshoot_packages`

Data type: `Boolean`

manage the setroubleshoot packages

##### <a name="setroubleshoot_package_names"></a>`setroubleshoot_package_names`

Data type: `Array[String]`

the names of the setroubleshoot packages

Default value: `[]`

##### <a name="module_build_root"></a>`module_build_root`

Data type: `Stdlib::Absolutepath`

directory where modules are built. Defaults to `$vardir/puppet-selinux`

Default value: `"${facts['puppet_vardir']}/puppet-selinux"`

##### <a name="default_builder"></a>`default_builder`

Data type: `Enum['refpolicy', 'simple']`

which builder to use by default with selinux::module

Default value: `'simple'`

##### <a name="boolean"></a>`boolean`

Data type: `Optional[Hash]`

Hash of selinux::boolean resource parameters

Default value: ``undef``

##### <a name="fcontext"></a>`fcontext`

Data type: `Optional[Hash]`

Hash of selinux::fcontext resource parameters

Default value: ``undef``

##### <a name="module"></a>`module`

Data type: `Optional[Hash]`

Hash of selinux::module resource parameters

Default value: ``undef``

##### <a name="permissive"></a>`permissive`

Data type: `Optional[Hash]`

Hash of selinux::module resource parameters

Default value: ``undef``

##### <a name="port"></a>`port`

Data type: `Optional[Hash]`

Hash of selinux::port resource parameters

Default value: ``undef``

##### <a name="exec_restorecon"></a>`exec_restorecon`

Data type: `Optional[Hash]`

Hash of selinux::exec_restorecon resource parameters

Default value: ``undef``

## Defined types

### <a name="selinuxboolean"></a>`selinux::boolean`

Manage the state of an SELinux boolean.

#### Examples

##### Enable `named_write_master_zones` boolean

```puppet
selinux::boolean{ 'named_write_master_zones':
   ensure => 'on',
}
```

##### Ensure `named_write_master_zones` boolean is disabled

```puppet
selinux::boolean{ 'named_write_master_zones':
   ensure => 'off',
}
```

#### Parameters

The following parameters are available in the `selinux::boolean` defined type:

* [`ensure`](#ensure)
* [`persistent`](#persistent)

##### <a name="ensure"></a>`ensure`

Data type: `Variant[Boolean, Enum['on', 'off', 'present', 'absent']]`

Set to on or off

Default value: `'on'`

##### <a name="persistent"></a>`persistent`

Data type: `Boolean`

Set to false if you don't want it to survive a reboot.

Default value: ``true``

### <a name="selinuxexec_restorecon"></a>`selinux::exec_restorecon`

Will execute after all other SELinux changes have been applied, but before
Anchor['selinux::end']

#### Parameters

The following parameters are available in the `selinux::exec_restorecon` defined type:

* [`path`](#path)
* [`recurse`](#recurse)
* [`force`](#force)
* [`refreshonly`](#refreshonly)
* [`unless`](#unless)
* [`onlyif`](#onlyif)

##### <a name="path"></a>`path`

Data type: `Stdlib::Absolutepath`

The path to run restorecon on. Defaults to resource title.

Default value: `$title`

##### <a name="recurse"></a>`recurse`

Data type: `Boolean`

Whether restorecon should recurse. Defaults to true

Default value: ``true``

##### <a name="force"></a>`force`

Data type: `Boolean`

Whether restorecon should use force.  Defaults to false.

Default value: ``false``

##### <a name="refreshonly"></a>`refreshonly`

Data type: `Boolean`

see the Exec resource

Default value: ``true``

##### <a name="unless"></a>`unless`

Data type: `Optional[String]`

see the Exec resource

Default value: ``undef``

##### <a name="onlyif"></a>`onlyif`

Data type: `Optional[String]`

see the Exec resource

Default value: ``undef``

### <a name="selinuxfcontext"></a>`selinux::fcontext`

For fcontext equivalences, see selinux::fcontext::equivalence

* **See also**
  * selinux::fcontext::equivalence

#### Examples

##### Add a file-context for mysql log files at non standard location

```puppet
selinux::fcontext{'set-mysql-log-context':
  seltype  => 'mysqld_log_t',
  pathspec => '/u01/log/mysql(/.*)?',
}
```

##### Add a file-context only for directory types

```puppet
selinux::fcontext{'/u/users/[^/]*':
  filetype => 'd',
  seltype  => 'user_home_dir_t' ,
}
```

#### Parameters

The following parameters are available in the `selinux::fcontext` defined type:

* [`ensure`](#ensure)
* [`seltype`](#seltype)
* [`seluser`](#seluser)
* [`pathspec`](#pathspec)
* [`filetype`](#filetype)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['absent', 'present']`

The desired state of the resource. Default: 'present'

Default value: `'present'`

##### <a name="seltype"></a>`seltype`

Data type: `Optional[String]`

String A particular SELinux type, like "mysqld_log_t"

Default value: ``undef``

##### <a name="seluser"></a>`seluser`

Data type: `Optional[String]`

String A particular SELinux user, like "sysadm_u"

Default value: ``undef``

##### <a name="pathspec"></a>`pathspec`

Data type: `String`

String An semanage fcontext-formatted path specification,
like "/var/log/mysql(/.*)?". Defaults to title

Default value: `$title`

##### <a name="filetype"></a>`filetype`

Data type: `Optional[String]`

File type the context applies to (i.e. regular file, directory, block device, all files, etc.)
- Types:
    - a = all files (default value if not restricting filetype)
    - f = regular file
    - d = directory
    - c = character device
    - b = block device
    - s = socket
    - l = symbolic link
    - p = named pipe

Default value: `'a'`

### <a name="selinuxfcontextequivalence"></a>`selinux::fcontext::equivalence`

Manage SELinux fcontext equivalences

#### Examples

##### Make /opt/wordpress equivalent to /usr/share/wordpress

```puppet
selinux::fcontext::equivalence { '/opt/wordpress':
  ensure => 'present',
  target => '/usr/share/wordpress',
}
```

#### Parameters

The following parameters are available in the `selinux::fcontext::equivalence` defined type:

* [`path`](#path)
* [`target`](#target)
* [`ensure`](#ensure)

##### <a name="path"></a>`path`

Data type: `String`

the path to define and equivalence for. Default: Resource title

Default value: `$title`

##### <a name="target"></a>`target`

Data type: `String`

the path that this resource will be equivalent to.

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

the desired state of the equivalence. Default: present

Default value: `'present'`

### <a name="selinuxmodule"></a>`selinux::module`

This class will either install or uninstall a SELinux module from a running system.
This module allows an admin to keep .te files in text form in a repository, while
allowing the system to compile and manage SELinux modules.

Concepts incorporated from:
http://stuckinadoloop.wordpress.com/2011/06/15/puppet-managed-deployment-of-selinux-modules/

#### Examples

##### compile and load the apache module - does not require make or the policy

```puppet
devel package
selinux::module{ 'apache':
  ensure    => 'present',
  source_te => 'puppet:///modules/selinux/apache.te',
  builder   => 'simple'
}
```

##### compile a module the refpolicy way. It will install the policy devel and

```puppet
dependent packages like make.
selinux::module{ 'mymodule':
  ensure    => 'present',
  source_te => 'puppet:///modules/profile/selinux/mymodule.te',
  source_fc => 'puppet:///modules/profile/selinux/mymodule.fc',
  source_if => 'puppet:///modules/profile/selinux/mymodule.if',
  builder   => 'refpolicy'
}
```

##### compile and load a module from inline content

```puppet
$content = @("END")
  policy_module(zabbix_fix, 0.1)
  require {
    type zabbix_t;
    type unreserved_port_t;
    class tcp_socket name_connect;
  }
  allow zabbix_t unreserved_port_t:tcp_socket name_connect;
  | END
selinux::module{ 'zabbix_fix':
  ensure     => 'present',
  content_te => $content,
  builder    => 'simple'
}
```

#### Parameters

The following parameters are available in the `selinux::module` defined type:

* [`ensure`](#ensure)
* [`source_pp`](#source_pp)
* [`source_te`](#source_te)
* [`source_fc`](#source_fc)
* [`source_if`](#source_if)
* [`content_te`](#content_te)
* [`content_fc`](#content_fc)
* [`content_if`](#content_if)
* [`builder`](#builder)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['absent', 'present']`

present or absent

Default value: `'present'`

##### <a name="source_pp"></a>`source_pp`

Data type: `Optional[String]`

the source file (either a puppet URI or local file) of a pre-compiled SELinux policy package.
Mutually excludsive with using source files.

Default value: ``undef``

##### <a name="source_te"></a>`source_te`

Data type: `Optional[String]`

the source file (either a puppet URI or local file) of the SELinux .te file

Default value: ``undef``

##### <a name="source_fc"></a>`source_fc`

Data type: `Optional[String]`

the source file (either a puppet URI or local file) of the SELinux .fc file

Default value: ``undef``

##### <a name="source_if"></a>`source_if`

Data type: `Optional[String]`

the source file (either a puppet URI or local file) of the SELinux .if file

Default value: ``undef``

##### <a name="content_te"></a>`content_te`

Data type: `Optional[String]`

content of the SELinux .te file

Default value: ``undef``

##### <a name="content_fc"></a>`content_fc`

Data type: `Optional[String]`

content of the SELinux .fc file

Default value: ``undef``

##### <a name="content_if"></a>`content_if`

Data type: `Optional[String]`

content of the SELinux .if file

Default value: ``undef``

##### <a name="builder"></a>`builder`

Data type: `Optional[Enum['simple', 'refpolicy']]`

either 'simple' or 'refpolicy'. The simple builder attempts to use checkmodule
to build the module, whereas 'refpolicy' uses the refpolicy framework, but requires 'make'

Default value: ``undef``

### <a name="selinuxpermissive"></a>`selinux::permissive`

Set SELinux type to permissive

#### Examples

##### Mark oddjob_mkhomedir_t permissive

```puppet
selinux::permissive { 'oddjob_mkhomedir_t':
  ensure => 'present'
}
```

#### Parameters

The following parameters are available in the `selinux::permissive` defined type:

* [`ensure`](#ensure)
* [`seltype`](#seltype)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Set to present to add or absent to remove a permissive mode of a type

Default value: `'present'`

##### <a name="seltype"></a>`seltype`

Data type: `String`

A particular selinux type to make permissive, like "oddjob_mkhomedir_t"

Default value: `$title`

### <a name="selinuxport"></a>`selinux::port`

This method will manage a local network port context setting, and will
persist it across reboots.

#### Examples

##### Add port-context syslogd_port_t to port 8514/tcp

```puppet
selinux::port { 'allow-syslog-relp':
  ensure   => 'present',
  seltype  => 'syslogd_port_t',
  protocol => 'tcp',
  port     => 8514,
}
```

#### Parameters

The following parameters are available in the `selinux::port` defined type:

* [`ensure`](#ensure)
* [`seltype`](#seltype)
* [`protocol`](#protocol)
* [`port`](#port)
* [`port_range`](#port_range)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Set to present to add or absent to remove a port context.

Default value: `'present'`

##### <a name="seltype"></a>`seltype`

Data type: `String`

An SELinux port type

##### <a name="protocol"></a>`protocol`

Data type: `Enum['tcp', 'udp']`

Either 'tcp', 'udp', 'ipv4' or 'ipv6'

##### <a name="port"></a>`port`

Data type: `Optional[Integer[1,65535]]`

A network port number, like 8514,

Default value: ``undef``

##### <a name="port_range"></a>`port_range`

Data type: `Optional[Tuple[Integer[1,65535], 2, 2]]`

A port-range tuple, eg. [9090, 9095].

Default value: ``undef``

## Resource types

### <a name="selinux_fcontext"></a>`selinux_fcontext`

Manage SELinux fcontext definitions. You should use selinux::fcontext instead of this directly.

#### Properties

The following properties are available in the `selinux_fcontext` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `file_type`

Valid values: `%r{^[abcdflps]$}`

The file type to match

Default value: `a`

##### `selrange`

Valid values: `%r{\w+}`

The SELinux range

##### `selrole`

Valid values: `%r{\w+}`

The SELinux role

##### `seltype`

Valid values: `%r{\w+}`, `<<none>>`

The SELinux type to apply to the paths

##### `seluser`

Valid values: `%r{\w+}`

The SELinux user name

#### Parameters

The following parameters are available in the `selinux_fcontext` type.

* [`pathspec`](#pathspec)
* [`provider`](#provider)
* [`title`](#title)

##### <a name="pathspec"></a>`pathspec`

Path regular expression

##### <a name="provider"></a>`provider`

The specific backend to use for this `selinux_fcontext` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="title"></a>`title`

The namevar. Should be of the format pathspec_filetype

### <a name="selinux_fcontext_equivalence"></a>`selinux_fcontext_equivalence`

Manage SELinux fcontext equivalence definitions. You should use selinux::fcontext instead of this directly.

#### Properties

The following properties are available in the `selinux_fcontext_equivalence` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `target`

The target of the equivalence. ie. the path that this resource will be equivalent to

#### Parameters

The following parameters are available in the `selinux_fcontext_equivalence` type.

* [`path`](#path)
* [`provider`](#provider)

##### <a name="path"></a>`path`

The path to set equivalence for

##### <a name="provider"></a>`provider`

The specific backend to use for this `selinux_fcontext_equivalence` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

### <a name="selinux_permissive"></a>`selinux_permissive`

Manage SELinux permissive types.

#### Properties

The following properties are available in the `selinux_permissive` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `selinux_permissive` type.

* [`local`](#local)
* [`provider`](#provider)
* [`seltype`](#seltype)

##### <a name="local"></a>`local`

Valid values: ``true``, ``false``

A read-only attribue indicating whether the type is locally customized

##### <a name="provider"></a>`provider`

The specific backend to use for this `selinux_permissive` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="seltype"></a>`seltype`

namevar

The SELinux type that should be permissive

### <a name="selinux_port"></a>`selinux_port`

Manage SELinux port definitions. You should use selinux::port instead of this directly.

#### Properties

The following properties are available in the `selinux_port` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `high_port`

The high end of the port range to manage

##### `low_port`

The low end of the port range to manage

##### `protocol`

Valid values: `tcp`, `udp`

The protocol of the SELinux port definition

##### `seltype`

The SELinux type of the SELinux port definition

##### `source`

Valid values: `policy`, `local`

Source of the port configuration - either policy or local

#### Parameters

The following parameters are available in the `selinux_port` type.

* [`provider`](#provider)
* [`title`](#title)

##### <a name="provider"></a>`provider`

The specific backend to use for this `selinux_port` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="title"></a>`title`

Should be of the form "protocol_lowport-highport" or the type may misbehave

